@@ -1,7 +1,7 @@
 # coding: utf-8
 from otrs_somconnexio.otrs_models.provision_ticket import ProvisionTicket
 from otrs_somconnexio.otrs_models.adsl_dynamic_fields import ADSLDynamicFields
-from otrs_somconnexio.otrs_models.configurations.adsl_ticket import ADSLTicketConfiguration
+from otrs_somconnexio.otrs_models.configurations.provision.adsl_ticket import ADSLTicketConfiguration
 
 
 class ADSLTicket(ProvisionTicket):
