@@ -28,6 +28,7 @@ class InternetData(object):
         vdf_fiber_coverage,
         orange_fiber_coverage,
         type,
+        technology,
         previous_contract_address="",
         previous_contract_phone="",
         mobile_pack_contracts="",
@@ -44,6 +45,7 @@ class InternetData(object):
         self.previous_owner_name = previous_owner_name
         self.previous_owner_surname = previous_owner_surname
         self.product = product
+        self.technology = technology
 
         # Common Internet the Tickets
         self.service_address = service_address
