@@ -13,7 +13,8 @@ class UnblockMobilePackTicket(UpdateTicketDF):
     Unblock is to change the DynamicField_recuperarProvisio to 1
     """
 
-    def __init__(self, ticket_number, introduced_date):
+    def __init__(self, ticket_number, activation_date, introduced_date):
+        self.activation_date = activation_date
         self.introduced_date = introduced_date
         super().__init__(ticket_number)
 
@@ -22,6 +23,9 @@ class UnblockMobilePackTicket(UpdateTicketDF):
             DynamicField(name='recuperarProvisio', value=1),
         ]
         if bool(ticket.dynamic_field_get("SIMrebuda").value):
+            dynamic_fields.append(
+                DynamicField(name="dataActivacioLiniaMobil", value=self.activation_date),
+            )
             dynamic_fields.append(
                 DynamicField(name="dataIntroPlataforma", value=self.introduced_date),
             )
