@@ -46,6 +46,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'previous_provider',
             'product',
             'has_sim',
+            'sim_delivery_tracking_code',
             'type',
             'delivery_street',
             'delivery_city',
@@ -525,3 +526,17 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["OdooContractRefRelacionat"], "72")
+
+
+    def test_sim_delivery_tracking_code(self):
+        self.mobile_data.sim_delivery_tracking_code = "72"
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["CorreusTrackingCode"], "72")
