@@ -23,6 +23,8 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             'name',
             'vat_number',
             'phone',
+            'has_active_contracts',
+            'language'
         ])
         self.service_data = Mock(spec=[
             'order_id',
@@ -53,6 +55,7 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
             'type',
             'product',
             'previous_internal_provider',
+            'technology',
         ])
 
         self.router_4G_otrs_process_id = "Router4GProcessID"
@@ -164,6 +167,45 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["NIFNIESoci"], "NIFCode")
 
+    def test_has_active_contracts_field(self):
+        self.customer_data.has_active_contracts = True
+
+        dynamic_fields = Router4GDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.router_4G_otrs_process_id,
+            self.router_4G_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "1")
+
+    def test_has_active_contracts_false_field(self):
+        self.customer_data.has_active_contracts = False
+
+        dynamic_fields = Router4GDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.router_4G_otrs_process_id,
+            self.router_4G_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["teContractesActius"], "0")
+
+    def test_language_field(self):
+        self.customer_data.language = "ca_ES"
+
+        dynamic_fields = Router4GDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.router_4G_otrs_process_id,
+            self.router_4G_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["idioma"], "ca_ES")
+
     def test_IBAN_field(self):
         self.service_data.iban = "ES6621000418401234567891"
 
@@ -520,3 +562,16 @@ class Router4GDynamicFieldsTestCase(unittest.TestCase):
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertNotIn("proveidorPrevi", dynamic_fields_dct.keys())
+
+    def test_tecnhology(self):
+        self.service_data.technology = "4G"
+
+        dynamic_fields = Router4GDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.router_4G_otrs_process_id,
+            self.router_4G_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["TecDelServei"], "4G")
\ No newline at end of file
