@@ -11,10 +11,10 @@ class Router4GTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
     def test_build_ticket(self, MockTicket):
         customer_data = Mock(spec=['id'])
-        service_data = Mock(spec=['order_id'])
+        service_data = Mock(spec=['order_id', 'technology'])
 
         expected_ticket_arguments = {
-            "Title": "Sol·licitud 4G {}".format(service_data.order_id),
+            "Title": "Ticket#{} - Només 4G".format(service_data.order_id),
             "Type": Router4GTicketConfiguration.type,
             "Queue": Router4GTicketConfiguration.queue,
             "State": Router4GTicketConfiguration.state,
@@ -31,15 +31,16 @@ class Router4GTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockInternetArticle):
         customer_data = Mock(spec=[])
-        service_data = Mock(spec=['order_id', 'notes'])
+        service_data = Mock(spec=['order_id', 'notes', 'technology'])
 
         mock_internet_article = MockInternetArticle.return_value
 
         Router4GTicket(service_data, customer_data)._build_article()
 
         MockInternetArticle.assert_called_with(
-            '4G',
+            service_data.technology,
             service_data.order_id,
+            '4G',
             service_data.notes
         )
         mock_internet_article.call.assert_called_once()
@@ -69,6 +70,8 @@ class Router4GTicketTestCase(unittest.TestCase):
             'first_name',
             'name',
             'vat_number',
+            'has_active_contracts',
+            'language',
         ])
         service_data = Mock(spec=[
             'order_id',
@@ -99,6 +102,7 @@ class Router4GTicketTestCase(unittest.TestCase):
             'type',
             'product',
             'previous_internal_provider',
+            'technology',
         ])
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
